@@ -11,7 +11,8 @@ class ParseCappReport(HTMLParser.HTMLParser):
 
 def getCoursesTaken(html):
     parser = ParseCappReport()
-    html_text = parser.feed(html).data_stack
+    parser.feed(html)
+    html_text = parser.data_stack
     courses = []
     for i in range(len(html_text)):
         if ((html_text[i] == "Grd" or re.match(r"^((^[A-F](-|\+))|P|(NC)|(AP)|(Reg))$", html_text[i]))
